@@ -34,13 +34,13 @@ from . import (
   hookdepends,
   infodirectory,
   javafiles,
-  kdeprograms,
   libtool,
   licensepkg,
   lotsofdocs,
   missingbackups,
   pathdepends,
   perllocal,
+  pcdepends,
   permissions,
   py_mtime,
   pydepends,
