@@ -20,14 +20,9 @@
 # 
 
 import getopt
-import imp
 import os
-import re
-import shutil
-import string
 import sys
 import tarfile
-import types
 
 import Namcap.depends
 import Namcap.tags
@@ -78,8 +73,12 @@ def check_rules_exclude(optlist):
 	return args_used
 
 def show_messages(name, key, messages):
+	colored_key = {'E': '\033[91mE\033[00m', 'W': '\033[93mW\033[00m', 'I': '\033[92mI\033[00m'}
 	for msg in messages:
-		print("%s %s: %s" % (name, key, Namcap.tags.format_message(msg)))
+		if sys.stdout.isatty():
+			print("%s %s: %s" % (name, colored_key[key], Namcap.tags.format_message(msg)))
+		else:
+			print("%s %s: %s" % (name, key, Namcap.tags.format_message(msg)))
 
 def process_realpackage(package, modules):
 	"""Runs namcap checks over a package tarball"""
@@ -248,9 +247,9 @@ for package in packages:
 
 	if os.path.isfile(package) and tarfile.is_tarfile(package):
 		process_realpackage(package, active_modules)
-	elif package.endswith('PKGBUILD'):
+	elif 'PKGBUILD' in package:
 		process_pkgbuild(package, active_modules)
 	else:
-		print("Error: Cannot process %s" % package)
+		print("Error: %s not package or PKGBUILD" % package)
 
 # vim: set ts=4 sw=4 noet:
